@@ -30,6 +30,7 @@ from __future__ import unicode_literals
 
 from functools import partial
 from textwrap import dedent
+import warnings
 
 from lck.lang import unset
 
@@ -44,6 +45,7 @@ class ChoicesEntry(object):
         self.raw = description
         self.global_id = Choice.global_id
         self.name = name
+        self.__shifted__ = []
         ChoicesEntry.global_id += 1
 
     @property
@@ -68,7 +70,7 @@ class ChoicesEntry(object):
     def __lshift__(self, other):
         """Unholy method for adding custom attributes to choices
         at declaration time. While this will cringe purists, it really
-        works well when you really need it. For example::
+        works well when you need it. For example::
 
             class Color(Choices):
                 _ = Choices.Choice
@@ -92,6 +94,7 @@ class ChoicesEntry(object):
         while defining choices and while using them), please let me know.
         """
         for key, value in other.iteritems():
+            self.__shifted__.append(key)
             setattr(self, key, value)
         return self
 
@@ -99,8 +102,8 @@ class ChoicesEntry(object):
 class ChoiceGroup(ChoicesEntry):
     """A group of choices."""
 
-    def __init__(self, id):
-        super(ChoiceGroup, self).__init__('', id=id)
+    def __init__(self, id, description=''):
+        super(ChoiceGroup, self).__init__(description, id=id)
         self.choices = []
 
 
@@ -143,6 +146,7 @@ def _getter(name, given, returns, found, getter):
 
 class _ChoicesMeta(type):
     def __new__(meta, classname, bases, classDict):
+        groups = []
         values = []
         for k, v in classDict.items():
             if isinstance(v, ChoicesEntry):
@@ -155,14 +159,19 @@ class _ChoicesMeta(type):
             if isinstance(choice, ChoiceGroup):
                 last_choice_id = choice.id
                 group = choice
+                groups.append(group)
             else:
                 if group:
                     group.choices.append(choice)
                     choice.group = group
+                    for shifted in group.__shifted__:
+                        if not hasattr(choice, shifted):
+                            setattr(choice, shifted, getattr(group, shifted))
                 if choice.id == -255:
                     last_choice_id += 1
                     choice.id = last_choice_id
                 last_choice_id = choice.id
+        classDict['__groups__'] = groups
         classDict['__choices__'] = values
         return type.__new__(meta, classname, bases, classDict)
 
@@ -170,7 +179,7 @@ class _ChoicesMeta(type):
 class Choices(list):
     __metaclass__ = _ChoicesMeta
 
-    def __init__(self, filter=(unset,), item=unset, pair=unset):
+    def __init__(self, filter=(unset,), item=unset, pair=unset, grouped=False):
         """Creates a list of pairs from the specified Choices class.
         By default, each pair consists of a numeric ID and the translated
         description. If `use_ids` is False, the name of the attribute
@@ -195,10 +204,23 @@ class Choices(list):
             item = lambda choice: (choice.id, choice.desc)
 
         filter = set(filter)
-        for choice in self.__choices__:
-            if choice.name in filter or (unset in filter and
-                                         isinstance(choice, Choice)):
-                self.append(item(choice))
+        if grouped and self.__groups__:
+            for group in self.__groups__:
+                group_choices = []
+                for choice in group.choices:
+                    if choice.name in filter or (unset in filter and
+                        isinstance(choice, Choice)):
+                        group_choices.append(item(choice))
+                if group_choices:
+                    self.append((group.desc, tuple(group_choices)))
+        else:
+            if grouped:
+                warnings.warn("Choices class called with grouped=True and no "
+                    "actual groups.")
+            for choice in self.__choices__:
+                if choice.name in filter or (unset in filter and
+                    isinstance(choice, Choice)):
+                    self.append(item(choice))
 
     FromName = _getter("FromName",
         given="name",
